==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/bean/LendresHEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 公司借证归还-表头
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corplendres")
public class LendresHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型(1-实物归还 2-使用归还)
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 发起人组织
    @TableField(value="pk_dept")
    private Long pkDept; // 发起人部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="pk_corpcertify")
    private String pkCorpcertify; // 原借用单(支持表头表体多选，此字段以逗号分割)
    @TableField(value="isthgh")
    private String isthgh; // 是否借用替换归还
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 

    @TableField(exist = false)
    @SubEntity(serviceName = "lendresBService", pidName = "pkCorplendres")
    private List<LendresBEntity> lendresBEntityList = new ArrayList<>();

    public List<LendresBEntity> getLendresBEntityList() {
        return lendresBEntityList;
    }

    public void setLendresBEntityList(List<LendresBEntity> lendresBEntityList) {
        this.lendresBEntityList = lendresBEntityList;
    }

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(String pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public String getIsthgh() {
        return isthgh;
    }

    public void setIsthgh(String isthgh) {
        this.isthgh = isthgh;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220616.071707-59-sources.jar: com/ejianc/certify/bean/LendresHEntity.java <==
package com.ejianc.certify.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 公司借证归还-表头
 * 
 * @author generator
 * 
 */
 @TableName("jzctm_corplendres")
public class LendresHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型(1-实物归还 2-使用归还)
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 发起人组织
    @TableField(value="pk_dept")
    private Long pkDept; // 发起人部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="pk_corpcertify")
    private String pkCorpcertify; // 原借用单(支持表头表体多选，此字段以逗号分割)
    @TableField(value="isthgh")
    private String isthgh; // 是否借用替换归还
    @TableField(value="vdef1")
    private String vdef1; // 
    @TableField(value="vdef10")
    private String vdef10; // 
    @TableField(value="vdef2")
    private String vdef2; // 
    @TableField(value="vdef3")
    private String vdef3; // 
    @TableField(value="vdef4")
    private String vdef4; // 
    @TableField(value="vdef5")
    private String vdef5; // 
    @TableField(value="vdef6")
    private String vdef6; // 
    @TableField(value="vdef7")
    private String vdef7; // 
    @TableField(value="vdef8")
    private String vdef8; // 
    @TableField(value="vdef9")
    private String vdef9; // 

    @TableField(exist = false)
    @SubEntity(serviceName = "lendresBService", pidName = "pkCorplendres")
    private List<LendresBEntity> lendresBVOList = new ArrayList<>();

    @TableField(exist = false)
    @SubEntity(serviceName = "lendresEService", pidName = "pkCorplendres")
    private List<LendresEEntity> lendresEVOList = new ArrayList<>();

    public List<LendresEEntity> getLendresEVOList() {
        return lendresEVOList;
    }

    public void setLendresEVOList(List<LendresEEntity> lendresEVOList) {
        this.lendresEVOList = lendresEVOList;
    }

    public List<LendresBEntity> getLendresBVOList() {
        return lendresBVOList;
    }

    public void setLendresBVOList(List<LendresBEntity> lendresBVOList) {
        this.lendresBVOList = lendresBVOList;
    }

    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getPkCorpcertify() {
        return pkCorpcertify;
    }

    public void setPkCorpcertify(String pkCorpcertify) {
        this.pkCorpcertify = pkCorpcertify;
    }
    public String getIsthgh() {
        return isthgh;
    }

    public void setIsthgh(String isthgh) {
        this.isthgh = isthgh;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }
    
}
